/**
 * Filter Store: Shared features.
 *
 * @description Define all filter store shared functions in this file.
 */
import { get, writable, } from 'svelte/store';
export const sectionFunct = (keys, openDefault) => {
    if (!Array.isArray(keys))
        throw 'Value must be an array';
    const defaultValue = (keys => {
        const res = {};
        keys.forEach(key => {
            res[String(key)] = false;
        });
        return res;
    })(keys);
    const value = writable(defaultValue);
    const open = (id) => {
        if (!id || typeof id !== 'string' || !Object.keys(defaultValue).includes(id))
            return;
        const currValues = get(value);
        for (const prop in currValues) {
            currValues[prop] = prop === id;
        }
        value.set(currValues);
    };
    const closeAll = () => {
        const currValues = get(value);
        for (const prop of Object.keys(currValues)) {
            currValues[prop] = false;
        }
        value.set(currValues);
    };
    const reset = () => value.set(defaultValue);
    if (openDefault)
        open(openDefault);
    return {
        ...value,
        open,
        reset,
        closeAll,
    };
};
