/// <reference types="svelte" />
/**
 * Filters custom store.
 *
 * @description Define all Filters custom store functions in this file.
 */
import { type Readable, type Writable } from 'svelte/store';
import { type FilterCustomIds, type IFilterJsonValues, type IFiltersCustom, type IFiltersCustomOpts, type IFilterCustom } from '../../../types';
export declare const custom: {
    updateValue: (id: FilterCustomIds, newValue?: IFilterCustom['value']) => void;
    values: Readable<IFiltersCustom>;
    reset: () => void;
    resetValue: (id: FilterCustomIds) => void;
    updateValues: (filters: IFilterJsonValues) => void;
    getDefaultValue: (id: FilterCustomIds) => string | number | boolean | undefined;
    resetWithValues: (filters: IFilterJsonValues) => void;
    objectValues: Readable<{
        id: FilterCustomIds;
        value: string | number | boolean;
        unit?: string | undefined;
    }[]>;
    jsonValues: Readable<string>;
    valuesWithLocales: Readable<IFiltersCustomOpts>;
    valuesNotInDefault: {
        list: Readable<{
            "border-width": boolean;
            "border-style": boolean;
            "border-radius": boolean;
            "border-color": boolean;
            "box-shadow--x": boolean;
            "box-shadow--y": boolean;
            "box-shadow--spread": boolean;
            "box-shadow--blur": boolean;
            "box-shadow--inset": boolean;
            "box-shadow--color": boolean;
            "filter--blur": boolean;
            "filter--brightness": boolean;
            "filter--contrast": boolean;
            "filter--grayscale": boolean;
            "filter--hue-rotate": boolean;
            "filter--invert": boolean;
            "filter--opacity": boolean;
            "filter--saturate": boolean;
            "filter--sepia": boolean;
        }>;
        count: Readable<number>;
        countBySection: Readable<{
            filter: number;
            border: number;
            "box-shadow": number;
            animation: number;
        }>;
    };
    section: {
        open: (id: string | number) => void;
        reset: () => void;
        closeAll: () => void;
        set(this: void, value: {
            [key: string]: boolean;
        }): void;
        update(this: void, updater: import("svelte/store").Updater<{
            [key: string]: boolean;
        }>): void;
        subscribe(this: void, run: import("svelte/store").Subscriber<{
            [key: string]: boolean;
        }>, invalidate?: import("svelte/store").Invalidator<{
            [key: string]: boolean;
        }> | undefined): import("svelte/store").Unsubscriber;
    };
    limit: Writable<number | undefined>;
    isBlocked: Readable<boolean>;
    set(this: void, value: IFiltersCustomOpts): void;
    update(this: void, updater: import("svelte/store").Updater<IFiltersCustomOpts>): void;
    subscribe(this: void, run: import("svelte/store").Subscriber<IFiltersCustomOpts>, invalidate?: import("svelte/store").Invalidator<IFiltersCustomOpts> | undefined): import("svelte/store").Unsubscriber;
    default: IFiltersCustomOpts;
    defaultInArray: IFiltersCustom;
    defaultToExport: {
        id: FilterCustomIds;
        value: string | number | boolean;
        unit?: string | undefined;
    }[];
};
