/**
 * TYPES.
 *
 * @description File for set core types.
 */
import type { IconDefinition } from '@fortawesome/free-solid-svg-icons';
import type { ComponentType } from 'svelte';
import type { locales } from './filters/locales/main.ts';
/**
 * ****************************************************************************.
 * CONSTANTS
 * ****************************************************************************.
 */
export declare const componentTypes: {
    readonly btn: {
        readonly light: "light";
        readonly neutral: "neutral";
        readonly primary: "primary";
        readonly secondary: "secondary";
        readonly gray: "gray";
        readonly grayReverse: "grayReverse";
        readonly success: "success";
        readonly error: "error";
        readonly none: "none";
    };
    readonly checkbox: {
        readonly native: "native";
        readonly toggle: "toggle";
    };
    readonly codeEditor: {
        readonly json: "json";
    };
    readonly colorPicker: {
        readonly native: "native";
        readonly nativeAndOpacity: "native-opacity";
    };
    readonly text: {
        readonly main: "main";
        readonly native: "native";
        readonly transparent: "transparent";
    };
    readonly number: {
        readonly native: "native";
        readonly transparent: "transparent";
    };
    readonly radio: {
        readonly native: "native";
    };
    readonly range: {
        readonly native: "native";
    };
    readonly select: {
        readonly native: "native";
        readonly transparent: "transparent";
    };
    readonly option: {
        readonly btn: "btn";
        readonly section: "section";
        readonly checkbox: "checkbox";
        readonly codeEditor: "code-ditor";
        readonly colorPicker: "color-picker";
        readonly text: "text";
        readonly number: "number";
        readonly radio: "radio";
        readonly range: "range";
        readonly select: "select";
    };
    readonly filters: {
        readonly sidebar: "sidebar";
        readonly main: "main";
    };
    readonly accordion: {
        readonly section: "section";
        readonly item: "item";
    };
    readonly badge: {
        readonly primary: "primary";
        readonly secondary: "secondary";
        readonly gray: "gray";
        readonly neutral: "neutral";
        readonly transparent: "transparent";
        readonly success: "success";
        readonly error: "error";
        readonly warning: "warning";
    };
    readonly notification: {
        readonly error: "error";
        readonly warn: "warn";
        readonly success: "success";
        readonly info: "info";
    };
    readonly tooltip: {
        readonly main: "main";
        readonly info: "info";
    };
    readonly title: {
        readonly tooltipLeft: "tooltip-left";
        readonly tooltipRight: "tooltip-right";
    };
    readonly indicator: {
        readonly main: "main";
        readonly error: "error";
        readonly warn: "warn";
        readonly success: "success";
        readonly info: "info";
        readonly neutral: "neutral";
    };
};
export declare const componentPositions: {
    readonly tooltip: {
        readonly topStart: "top-start";
        readonly top: "top";
        readonly topEnd: "top-end";
        readonly rightStart: "right-start";
        readonly right: "right";
        readonly rightEnd: "right-end";
        readonly bottomStart: "bottom-start";
        readonly bottom: "bottom";
        readonly bottomEnd: "bottom-end";
        readonly leftStart: "left-start";
        readonly left: "left";
        readonly leftEnd: "left-end";
    };
    readonly indicator: {
        readonly bottom: "bottom";
        readonly right: "right";
        readonly left: "left";
        readonly top: "top";
        readonly bottomLeft: "bottom-left";
        readonly bottomRight: "bottom-right";
        readonly topLeft: "top-left";
        readonly topRight: "top-right";
    };
    readonly filters: {
        readonly sidebar: {
            readonly bottom: "bottom";
            readonly right: "right";
            readonly left: "left";
            readonly top: "top";
            readonly none: "none";
        };
        readonly btn: {
            readonly bottomLeft: "bottom-left";
            readonly bottomRight: "bottom-right";
            readonly topLeft: "top-left";
            readonly topRight: "top-right";
            readonly none: "none";
        };
    };
};
export declare const allowedFilterTabs: {
    readonly custom: 1;
    readonly preset: 2;
    readonly more: 3;
    readonly btn: 4;
};
export declare const filtersSectionsIds: {
    readonly custom: {
        readonly filter: "filter";
        readonly border: "border";
        readonly shadow: "box-shadow";
        readonly animation: "animation";
    };
    readonly presets: {
        readonly official: "official";
        readonly user: "user";
    };
    readonly more: {
        readonly copy: "copy";
        readonly addPreset: "add-preset";
    };
};
export declare const filterCustomIds: {
    readonly borderWidth: "border-width";
    readonly borderStyle: "border-style";
    readonly borderRadius: "border-radius";
    readonly borderColor: "border-color";
    readonly shadowX: "box-shadow--x";
    readonly shadowY: "box-shadow--y";
    readonly shadowSpread: "box-shadow--spread";
    readonly shadowBlur: "box-shadow--blur";
    readonly shadowInset: "box-shadow--inset";
    readonly shadowColor: "box-shadow--color";
    readonly filterBlur: "filter--blur";
    readonly filterBrightness: "filter--brightness";
    readonly filterContrast: "filter--contrast";
    readonly filterGrayscale: "filter--grayscale";
    readonly filterHueRotate: "filter--hue-rotate";
    readonly filterInvert: "filter--invert";
    readonly filterOpacity: "filter--opacity";
    readonly filterSaturation: "filter--saturate";
    readonly filterSepia: "filter--sepia";
};
export declare const filterCustomTypesIds: {
    readonly range: "range";
    readonly colorPicker: "color-picker";
    readonly radio: "radio";
    readonly checkbox: "checkbox";
    readonly select: "select";
};
export declare const unitValues: {
    readonly px: "px";
    readonly deg: "deg";
    readonly x100: "%";
};
export declare const sizeValues: {
    readonly extraSmall: "extra-small";
    readonly small: "small";
    readonly medium: "medium";
    readonly large: "large";
    readonly extraLarge: "extra-large";
};
/**
 * ****************************************************************************.
 * TYPE UTILS
 * ****************************************************************************.
 */
export type ObjectValues<Values> = Values[keyof Values];
export type RecursivePartial<T> = {
    [P in keyof T]?: T[P] extends object ? RecursivePartial<T[P]> : T[P];
};
export type ObjectTypeBasedInTypeKeys<Type, GeneralValueType> = {
    [K in keyof Type]: GeneralValueType;
};
export type OmitNeverInobjectValues<T> = Omit<T, {
    [K in keyof T]: T[K] extends never ? K : never;
}[keyof T]>;
export type CreateArrayWithLengthX<LENGTH extends number, ACC extends unknown[] = []> = ACC['length'] extends LENGTH ? ACC : CreateArrayWithLengthX<LENGTH, [...ACC, 1]>;
export type NumericRange<START_ARR extends number[], END extends number, ACC extends number = never> = START_ARR['length'] extends END ? ACC | END : NumericRange<[...START_ARR, 1], END, ACC | START_ARR['length']>;
/**
 * ****************************************************************************.
 * SHARED
 * ****************************************************************************.
 */
export type UnitValues = ObjectValues<typeof unitValues>;
export type SizeValues = ObjectValues<typeof sizeValues>;
export type SelectOpt<Value> = {
    value: Value;
    name?: string;
    disabled?: boolean;
    hidden?: boolean;
};
export type SelectAttr<Value> = {
    value: Value;
    opts: (SelectOpt<Value>)[];
};
export type SelectAttrs = SelectAttr<unknown>;
export type InputRangeSharedAttrs = {
    max: number;
    min: number;
    step: number;
};
export type InputNumberAttrs = InputRangeSharedAttrs;
export type InputRangeAttrs = InputRangeSharedAttrs & {
    unit?: UnitValues | SelectAttr<UnitValues>;
};
/**
 * ****************************************************************************.
 * COMPONETS
 * ****************************************************************************.
 */
/**
 * INPUTS.
 */
export type ComponentInputShared<Type> = {
    id: string;
    type: ObjectValues<Type>;
    customClasses?: string;
};
export type ComponentNot = ComponentInputShared<typeof componentTypes.notification>;
export type ComponentBtn = ComponentInputShared<typeof componentTypes.btn> & {
    href: string;
    ping: boolean;
    active: string | number | string[] | undefined | boolean;
    disabled?: boolean;
    tooltip?: Partial<ComponentTooltip> & {
        title?: string;
    };
    icon?: IconDefinition;
};
export type ComponentCheckbox = ComponentInputShared<typeof componentTypes.checkbox> & {
    value: boolean;
    disabled?: boolean;
};
export type ComponentColorPicker = ComponentInputShared<typeof componentTypes.colorPicker> & {
    value: string;
    disabled?: boolean;
};
export type ComponentText = ComponentInputShared<typeof componentTypes.number> & {
    value: string;
    disabled?: boolean;
    placeholder?: string;
};
export type ComponentNumber = ComponentInputShared<typeof componentTypes.number> & {
    value: number;
    opts?: InputNumberAttrs;
    disabled?: boolean;
};
export type ComponentSelect = ComponentInputShared<typeof componentTypes.select> & {
    value: string;
    opts?: SelectOpt<string>[];
    disabled?: boolean;
};
export type ComponentRadio = ComponentInputShared<typeof componentTypes.radio> & {
    value: string;
    opts?: SelectOpt<string>[];
    disabled?: boolean;
};
export type ComponentRange = ComponentInputShared<typeof componentTypes.range> & {
    value: number;
    opts?: InputRangeAttrs;
    inputValue: boolean;
    disabled?: boolean;
};
export type ComponentCodeEditor = ComponentInputShared<typeof componentTypes.codeEditor> & {
    value: string;
    readonly?: boolean;
    placeholder?: string;
    height?: string;
    width?: string;
};
export type ComponentTitle = ComponentInputShared<typeof componentTypes.title> & {
    value: string;
    desc?: string;
    link?: string;
    linkTarget?: '_blank' | '__self';
    tooltip?: Partial<ComponentTooltip>;
};
/**
 * OPTION.
 */
export type ComponentOptionShared<ValueType extends {
    value: ValueType['value'];
    opts?: ValueType['opts'];
}> = ComponentInputShared<typeof componentTypes.option> & {
    value?: ValueType['value'];
    opts?: ValueType['opts'];
    title?: Partial<ComponentTitle> & {
        value: ComponentTitle['value'];
    };
    disabled?: boolean | string;
    onChange?: (newValue: ValueType['value']) => void;
    onReset?: () => void;
};
export type ComponentOption = ComponentOptionShared<ComponentCheckbox> | ComponentOptionShared<ComponentText> | ComponentOptionShared<ComponentRadio> | ComponentOptionShared<ComponentNumber> | ComponentOptionShared<ComponentSelect> | ComponentOptionShared<ComponentRadio> | ComponentOptionShared<ComponentRange> | ComponentOptionShared<ComponentCodeEditor>;
/**
 * TAB.
 */
export type ComponentTabs = {
    items: {
        value: number;
        component: ComponentType;
        name: string;
        desc?: string;
        props?: object;
        indicator?: boolean;
    }[];
    activeTabValue?: number;
    customClasses: string;
    customBtnClasses: string;
};
/**
 * ACCORDION.
 */
export type ComponentAccordion = {
    title?: Partial<ComponentTitle> & {
        value: ComponentTitle['value'];
    };
    type: ObjectValues<typeof componentTypes.accordion>;
    open?: boolean;
};
/**
 * BADGE.
 */
export type ComponentBadge = ComponentInputShared<typeof componentTypes.badge> & {
    title: string;
    url?: string;
};
/**
 * TOOLTIP.
 */
export type ComponentTooltip = ComponentInputShared<typeof componentTypes.tooltip> & {
    position?: ObjectValues<typeof componentPositions.tooltip>;
    icon?: IconDefinition;
};
/**
 * INDICATOR.
 */
export type ComponentIndicator = Omit<ComponentInputShared<typeof componentTypes.indicator>, 'id'> & {
    position?: ObjectValues<typeof componentPositions.indicator>;
    title?: string;
    size?: SizeValues;
};
/**
 * SIDEBAR.
 */
export type ComponentSidebarContentFilters = {
    allowedItems?: ObjectValues<typeof allowedFilterTabs>[];
    width?: string;
    height?: string;
    customClasses?: string;
};
export type ComponentSidebarFilters = {
    position?: ObjectValues<typeof componentPositions.filters.sidebar>;
    content?: ComponentSidebarContentFilters;
};
export type ComponentBtnFilters = {
    position?: ObjectValues<typeof componentPositions.filters.btn>;
    title?: string;
    customClasses?: string;
    color?: ComponentBtn['type'];
    indicator?: ComponentIndicator;
    active?: boolean;
};
export type ComponentFilters = ComponentInputShared<typeof componentTypes.filters> & {
    value?: string;
    title?: string;
    active: boolean;
    toSelectors: string[];
    btn?: ComponentBtnFilters;
    locales?: RecursivePartial<typeof locales>;
    document?: Document;
    position?: ObjectValues<typeof componentPositions.filters.sidebar>;
    content?: ComponentSidebarContentFilters;
    optionsLimit?: number;
    valuesChanged?: number;
};
/**
 * ****************************************************************************.
 * FILTERS
 * ****************************************************************************.
 */
export type FilterCustomIds = ObjectValues<typeof filterCustomIds>;
export type IFilterCustomShared<Type extends {
    value: Type['value'];
    opts?: Type['opts'];
}, Id> = {
    id: FilterCustomIds;
    title: Partial<ComponentTitle> & {
        value: ComponentTitle['value'];
    };
    type: Id;
    value: Type['value'];
    opts?: Type['opts'];
};
export type IFilterCustomSharedWithRequiredOpts<Type extends {
    value: Type['value'];
    opts?: Type['opts'];
}, Id> = Omit<IFilterCustomShared<Type, Id>, 'opts'> & {
    opts: NonNullable<Type['opts']>;
};
export type IFilterJsonValue = {
    id: FilterCustomIds;
    value: string | number | boolean;
};
export type IFilterJsonValues = IFilterJsonValue[];
export type FiltersCustomToExport = {
    values: {
        id: FilterCustomIds;
        value: string | number | boolean;
        unit?: string;
    }[];
    presets: {
        value: string;
        customList: [] | IFiltersPresets;
    };
    hide: boolean;
};
export type IFilterCustom = IFilterCustomShared<ComponentCheckbox, typeof filterCustomTypesIds.checkbox> | IFilterCustomShared<ComponentColorPicker, typeof filterCustomTypesIds.colorPicker> | IFilterCustomSharedWithRequiredOpts<ComponentRange, typeof filterCustomTypesIds.range> | IFilterCustomSharedWithRequiredOpts<ComponentRadio, typeof filterCustomTypesIds.radio> | IFilterCustomSharedWithRequiredOpts<ComponentSelect, typeof filterCustomTypesIds.select>;
export type IFiltersCustom = IFilterCustom[];
export type FiltersCustomOptsValues = {
    title: Partial<ComponentTitle> & {
        value: ComponentTitle['value'];
    };
    value: IFiltersCustom;
};
export type IFiltersCustomType = ObjectValues<typeof filtersSectionsIds.custom>;
export type IFiltersCustomOpts = Omit<ObjectTypeBasedInTypeKeys<typeof filtersSectionsIds.custom, FiltersCustomOptsValues>, 'animation'>;
/**
 * ****************************************************************************.
 * PRESETS
 * ****************************************************************************.
 */
export type IFiltersPresetStyle = IFilterJsonValue;
export type IFiltersPresetStyles = IFiltersPresetStyle[];
export type IFiltersPreset = {
    id: string;
    name: string;
    opts: {
        color: string;
        gradientColor?: string;
    };
    value: IFiltersPresetStyles;
};
export type IFiltersPresets = IFiltersPreset[];
/**
 * ****************************************************************************.
 * STORE
 * ****************************************************************************.
 */
export type AddStylesParams = {
    customValues: IFiltersCustom;
    presetsValue: string;
    selectors: string[];
    isHide: boolean;
    id: string;
};
export type AddStylesConstructorParams = AddStylesParams & {
    document: Document;
};
export type AddPresetParams = {
    name: string;
    color: string;
    value: IFiltersPresetStyles;
};
