/**
 * TYPES.
 *
 * @description File for set core types.
 */
/**
 * ****************************************************************************.
 * CONSTANTS
 * ****************************************************************************.
 */
export const componentTypes = {
    btn: {
        light: 'light',
        neutral: 'neutral',
        primary: 'primary',
        secondary: 'secondary',
        gray: 'gray',
        grayReverse: 'grayReverse',
        success: 'success',
        error: 'error',
        none: 'none',
    },
    checkbox: {
        native: 'native',
        toggle: 'toggle',
    },
    codeEditor: {
        json: 'json',
    },
    colorPicker: {
        native: 'native',
        nativeAndOpacity: 'native-opacity',
    },
    text: {
        main: 'main',
        native: 'native',
        transparent: 'transparent',
    },
    number: {
        native: 'native',
        transparent: 'transparent',
    },
    radio: {
        native: 'native',
    },
    range: {
        native: 'native',
    },
    select: {
        native: 'native',
        transparent: 'transparent',
    },
    option: {
        btn: 'btn',
        section: 'section',
        checkbox: 'checkbox',
        codeEditor: 'code-ditor',
        colorPicker: 'color-picker',
        text: 'text',
        number: 'number',
        radio: 'radio',
        range: 'range',
        select: 'select',
    },
    filters: {
        sidebar: 'sidebar',
        main: 'main',
    },
    accordion: {
        section: 'section',
        item: 'item',
    },
    badge: {
        primary: 'primary',
        secondary: 'secondary',
        gray: 'gray',
        neutral: 'neutral',
        transparent: 'transparent',
        success: 'success',
        error: 'error',
        warning: 'warning',
    },
    notification: {
        error: 'error',
        warn: 'warn',
        success: 'success',
        info: 'info',
    },
    tooltip: {
        main: 'main',
        info: 'info',
    },
    title: {
        tooltipLeft: 'tooltip-left',
        tooltipRight: 'tooltip-right',
    },
    indicator: {
        main: 'main',
        error: 'error',
        warn: 'warn',
        success: 'success',
        info: 'info',
        neutral: 'neutral',
    },
};
export const componentPositions = {
    tooltip: {
        topStart: 'top-start',
        top: 'top',
        topEnd: 'top-end',
        rightStart: 'right-start',
        right: 'right',
        rightEnd: 'right-end',
        bottomStart: 'bottom-start',
        bottom: 'bottom',
        bottomEnd: 'bottom-end',
        leftStart: 'left-start',
        left: 'left',
        leftEnd: 'left-end',
    },
    indicator: {
        bottom: 'bottom',
        right: 'right',
        left: 'left',
        top: 'top',
        bottomLeft: 'bottom-left',
        bottomRight: 'bottom-right',
        topLeft: 'top-left',
        topRight: 'top-right',
    },
    filters: {
        sidebar: {
            bottom: 'bottom',
            right: 'right',
            left: 'left',
            top: 'top',
            none: 'none',
        },
        btn: {
            bottomLeft: 'bottom-left',
            bottomRight: 'bottom-right',
            topLeft: 'top-left',
            topRight: 'top-right',
            none: 'none',
        },
    },
};
export const allowedFilterTabs = {
    custom: 1,
    preset: 2,
    more: 3,
    btn: 4,
};
export const filtersSectionsIds = {
    custom: {
        filter: 'filter',
        border: 'border',
        shadow: 'box-shadow',
        animation: 'animation',
    },
    presets: {
        official: 'official',
        user: 'user',
    },
    more: {
        copy: 'copy',
        addPreset: 'add-preset',
    },
};
export const filterCustomIds = {
    borderWidth: 'border-width',
    borderStyle: 'border-style',
    borderRadius: 'border-radius',
    borderColor: 'border-color',
    shadowX: 'box-shadow--x',
    shadowY: 'box-shadow--y',
    shadowSpread: 'box-shadow--spread',
    shadowBlur: 'box-shadow--blur',
    shadowInset: 'box-shadow--inset',
    shadowColor: 'box-shadow--color',
    filterBlur: 'filter--blur',
    filterBrightness: 'filter--brightness',
    filterContrast: 'filter--contrast',
    filterGrayscale: 'filter--grayscale',
    filterHueRotate: 'filter--hue-rotate',
    filterInvert: 'filter--invert',
    filterOpacity: 'filter--opacity',
    filterSaturation: 'filter--saturate',
    filterSepia: 'filter--sepia',
};
export const filterCustomTypesIds = {
    range: 'range',
    colorPicker: 'color-picker',
    radio: 'radio',
    checkbox: 'checkbox',
    select: 'select',
};
export const unitValues = {
    px: 'px',
    deg: 'deg',
    x100: '%',
};
export const sizeValues = {
    extraSmall: 'extra-small',
    small: 'small',
    medium: 'medium',
    large: 'large',
    extraLarge: 'extra-large',
};
